@@ -322,7 +322,7 @@ DataControlSource::DataControlSource(struct ::ext_data_control_source_v1 *id, QM
     for (const QString &format : formats) {
         offer(format);
     }
-    if (mimeData->hasText()) {
+    if (mimeData->hasText() && !m_mimeData->hasFormat(utf8Text())) {
         // ensure GTK applications get this mimetype to avoid them discarding the offer
         offer(QStringLiteral("text/plain;charset=utf-8"));
     }
